spoon.transports.LinkMessage

Package spoon :: Package transports :: Class LinkMessage |
[hide private]
[frames] | no frames]

# Class LinkMessage

source code

    object --+
             |
            LinkMessage

Link message is the wrapper which will contain messages sent between two directly connected nodes. This message just consists of a msg type (an int) and some arbitrary attachment. The msgtype determines what system will deal with the message. Since this is strictly for use between directly connected nodes, there's no need for src or destination fields.

Instance Methods | [hide private]
`` | __init__(self, msgtype=None, attach=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, msgtype=None, attach=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)